{% load i18n %}
<!doctype html>
<html lang="en">

<head>
    <title>{{ site.name }} {% trans "registration" %}</title>
</head>

<body>
<p>
    {% blocktrans with site_name=site.name %}
    The following user ({{ user }}) has asked to register an account at
    {{ site_name }}.
    {% endblocktrans %}
</p>
<p>
    {% blocktrans %}
    To approve this, please
    {% endblocktrans %}
    <a href="http://{{site.domain}}{% url 'registration_admin_approve' profile_id %}"> {% trans "click here" %}</a>.
</p>
<p>
    {% blocktrans with site_name=site.name %}
    Sincerely,
    {{ site_name }} Management
    {% endblocktrans %}
</p>
</body>

</html>

{% comment %}
**registration/admin_approve_email.html**

Used to generate the html body of the admin activation email. Should display a
link for an admin to approve activation of the account. This template has the
following context:

``profile_id``
    The id of the registration profile requesting approval

``site``
    An object representing the site on which the user registered;
    depending on whether ``django.contrib.sites`` is installed, this
    may be an instance of either ``django.contrib.sites.models.Site``
    (if the sites application is installed) or
    ``django.contrib.sites.requests.RequestSite`` (if not). Consult `the
    documentation for the Django sites framework
    <http://docs.djangoproject.com/en/dev/ref/contrib/sites/>`_ for
    details regarding these objects' interfaces.

``user``
    The new user account

``request``
    ``HttpRequest`` instance for better flexibility.
    For example it can be used to compute absolute approval URL:

        {{ request.scheme }}://{{ request.get_host }}{% url 'registration_admin_approve' profile_id %}
{% endcomment %}
